==> haskell-primitive-0.9.1.0-110.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive
version:              0.9.1.0
visibility:           public
id:                   primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
key:                  primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
license:              BSD-3-Clause
copyright:            (c) Roman Leshchinskiy 2009-2012
maintainer:           libraries@haskell.org
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/primitive
synopsis:             Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.

category:             Data
abi:                  1de0438a2e9fbf80ba0f382ee40bf4a9
exposed:              True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.Array
    Data.Primitive.ByteArray Data.Primitive.MVar
    Data.Primitive.MachDeps Data.Primitive.MutVar
    Data.Primitive.PrimArray Data.Primitive.PrimVar Data.Primitive.Ptr
    Data.Primitive.SmallArray Data.Primitive.Types

hidden-modules:
    Data.Primitive.Internal.Operations Data.Primitive.Internal.Read

import-dirs:          /usr/lib/ghc-9.6.6/site-local/primitive-0.9.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-0.9.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/primitive-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive
hs-libraries:         HSprimitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
include-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-0.9.1.0/include
depends:
    base-4.18.2.1 deepseq-1.4.8.1 template-haskell-2.20.0.0
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html:         /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-0.9.1.0-112-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive
version:              0.9.1.0
visibility:           public
id:                   primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
key:                  primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
license:              BSD-3-Clause
copyright:            (c) Roman Leshchinskiy 2009-2012
maintainer:           libraries@haskell.org
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/primitive
synopsis:             Primitive memory-related operations
description:
    This package provides various primitive memory-related operations.

category:             Data
abi:                  f55c4db5ba5924900bb59f60b3a01622
exposed:              True
exposed-modules:
    Control.Monad.Primitive Data.Primitive Data.Primitive.Array
    Data.Primitive.ByteArray Data.Primitive.MVar
    Data.Primitive.MachDeps Data.Primitive.MutVar
    Data.Primitive.PrimArray Data.Primitive.PrimVar Data.Primitive.Ptr
    Data.Primitive.SmallArray Data.Primitive.Types

hidden-modules:
    Data.Primitive.Internal.Operations Data.Primitive.Internal.Read

import-dirs:          /usr/lib/ghc-9.6.6/site-local/primitive-0.9.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-0.9.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/primitive-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive
hs-libraries:         HSprimitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
include-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-0.9.1.0/include
depends:
    base-4.18.2.1 deepseq-1.4.8.1 template-haskell-2.20.0.0
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-primitive/html/primitive.haddock
haddock-html:         /usr/share/doc/haskell-primitive/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
